# KnifeSwap release 2 by David Bowland
# ./addons/eventscripts/knifeswap/knifeswap.py

# >>> To configure this addon please see knifeswap.cfg (created when the addon is first loaded) <<<

"""
Provides a client command to swap between the knife and last active weapon. Requires only ES 2.0.0.248+
"""


import cfglib
import es
import langlib
import os.path
import playerlib

import psyco
psyco.full()


info = es.AddonInfo()
info.name     = 'KnifeSwap'
info.version  = '2'
info.basename = 'knifeswap'
info.url      = 'http://addons.eventscripts.com/addons/view/' + info.basename
info.author   = 'SuperDave'


###


config = cfglib.AddonCFG(es.getAddonPath(info.basename) + '/' + info.basename + '.cfg')

config.text(info.name + ' release %s options' % info.version)
config.text('./addons/eventscripts/%(basename)s/%(basename)s.cfg' % {'basename':info.basename})
config.text(info.url)
config.text('')
config.text('Load this addon with: es_load ' + info.basename)
config.text('\n')
config.text('To configure language settings for %s please see %s_languages.ini' % (info.name, info.basename))
config.text('\n')

config.text('***** Options *****')
cvar_announce_chat = config.cvar('knifeswap_announce_chat', 2, '0 = no change, 1 = announce knife swap command on the console at the beginning of the round, 2 = announce knife swap command in chat area at the beginning of the round')
cvar_announce_hud  = config.cvar('knifeswap_announce_hud',  1, '0 = no change, 1 = announce knife swap command in a HUD hint at the beginning of the round')

config.write()


###


def getLangText():
   lang_path = es.getAddonPath(info.basename) + '/%s_languages.ini' % info.basename
   if os.path.isfile(lang_path):
      return langlib.Strings(lang_path)

   else:
      es.dbgmsg(0, '%(name)s: Unable to load %(basename)s_languages.ini! Please ensure it is in the ./%(basename)s/ directory.' % {'name':info.name, 'basename':info.basename})
      return lambda x, y, z: '%s: %s_languages.ini not found' % (info.name, info.basename)

lang_text = getLangText()


###


def load():
   """
   Ensures critical server variables are created by the config
   """
   config.execute()


def round_start(event_var):
   chat = int(cvar_announce_chat)
   hud  = int(cvar_announce_hud)
   if not chat and not hud: return

   for userid in filter(lambda x: not es.getplayerprop(x, 'CBasePlayer.pl.deadflag'), es.getUseridList()):
      lang = playerlib.getPlayer(userid).get('lang')

      if chat:
         if chat == 1:
            es.cexec(userid, 'echo ' + remove_tags(lang_text('command announce', {}, lang)))
         else:
            es.tell(userid, '#multi', lang_text('command announce', {}, lang))

      if hud:
         hud_hint(userid, remove_tags(lang_text('command announce', {}, lang)))


def unload():
   es.unregclientcmd('knifeswap')

   for cvar in config.getCvars():
      es.ServerVar(cvar).set(0)


###


def swap_cmd():
   userid = es.getcmduserid()

   if es.createplayerlist(userid)[userid]['weapon'] == 'weapon_knife':
      es.cexec(userid, 'lastinv')

   else:
      es.sexec(userid, 'use weapon_knife')

if not es.exists('clientcommand', 'knifeswap'):
   es.regclientcmd('knifeswap', 'knifeswap/swap_cmd', 'Command to swap between the knife and last active weapon')


###


def hud_hint(userid, message):
   """Sends the player a HUD hint"""
   es.usermsg('create', 'knifeswap_hud', 'HintText')
   es.usermsg('write', 'short', 'knifeswap_hud', -1)
   es.usermsg('write', 'string', 'knifeswap_hud', message)
   es.usermsg('send', 'knifeswap_hud', userid)
   es.usermsg('delete', 'knifeswap_hud')


def remove_tags(text):
   """Removes #lightgreen, #green and #default tags from the supplied string"""
   return text.replace('#lightgreen', '').replace('#green', '').replace('#default', '')